@@ -21,12 +21,15 @@
 
 #include <config.h>
 
+#include <string.h>
 #include <sys/file.h>
 #include <X11/X.h>
 
 /* Gnome headers */
+#include <glib/gi18n.h>
 #include <gdk/gdkx.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
 
@@ -99,12 +102,24 @@ static void
 execute (char *cmd, gboolean sync)
 {
 	gboolean retval;
+	gchar **argv;
+	gint argc;
+	
+	retval = FALSE;
 
-	if (sync != FALSE)
-		retval = g_spawn_command_line_sync
-			(cmd, NULL, NULL, NULL, NULL);
-	else
-		retval = g_spawn_command_line_async (cmd, NULL);
+	if (g_shell_parse_argv (cmd, &argc, &argv, NULL)) {
+		if (sync != FALSE) {
+			retval = g_spawn_sync (g_get_home_dir (), 
+			                       argv, NULL, G_SPAWN_SEARCH_PATH,
+			                       NULL, NULL, NULL, NULL, NULL, NULL);
+		}
+		else {
+			retval = g_spawn_async (g_get_home_dir (), 
+			                        argv, NULL, G_SPAWN_SEARCH_PATH,
+			                        NULL, NULL, NULL, NULL);
+		}
+		g_strfreev (argv);
+	}
 
 	if (retval == FALSE)
 	{
@@ -638,7 +653,7 @@ do_www_action (Acme *acme, const char *url)
 	}
 
 	if (url == NULL)
-		command = g_strdup_printf (string, "about:blank");
+		command = g_strdup_printf (string, "");
 	else
 		command = g_strdup_printf (string, url);
 
@@ -789,6 +804,8 @@ do_sound_action (Acme *acme, int type)
 static void
 do_action (Acme *acme, int type)
 {
+	gchar *cmd;
+
 	switch (type) {
 	case MUTE_KEY:
 	case VOLUME_DOWN_KEY:
@@ -814,7 +831,12 @@ do_action (Acme *acme, int type)
 		do_sleep_action ("apm", "xset dpms force off");
 		break;
 	case SCREENSAVER_KEY:
-		execute ("xscreensaver-command -lock", FALSE);
+		if ((cmd = g_find_program_in_path ("gnome-screensaver-command")))
+			execute ("gnome-screensaver-command --lock", FALSE);
+		else
+			execute ("xscreensaver-command -lock", FALSE);
+
+		g_free (cmd);
 		break;
 	case HELP_KEY:
 		do_help_action (acme);
