@@ -656,7 +656,7 @@ GSwitchItConfigLockNextGroup (void)
 }
 
 void
-GSwitchIttConfigLockPrevGroup (void)
+GSwitchItConfigLockPrevGroup (void)
 {
 	int group = XklGetPrevGroup ();
 	XklLockGroup (group);
